==> cdk-remix-app-0.0.0.tar.gz: cdk-remix-app-0.0.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-remix-app",
    "version": "0.0.0",
    "description": "cdk-remix-app",
    "license": "Apache-2.0",
    "url": "https://github.com/rogerchi/cdk-remix-app.git",
    "long_description_content_type": "text/markdown",
    "author": "Roger Chi<roger@rogerchi.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/rogerchi/cdk-remix-app.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_remix-app",
        "cdk_remix-app._jsii"
    ],
    "package_data": {
        "cdk_remix-app._jsii": [
            "cdk-remix-app@0.0.0.jsii.tgz"
        ],
        "cdk_remix-app": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.24.0, <3.0.0",
        "aws-cdk.aws-apigatewayv2-alpha==2.24.0.a0",
        "aws-cdk.aws-apigatewayv2-integrations-alpha==2.24.0.a0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.72.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-remix-app-0.0.1.tar.gz: cdk-remix-app-0.0.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-remix-app",
    "version": "0.0.1",
    "description": "@rogerchi/cdk-remix-app",
    "license": "Apache-2.0",
    "url": "https://github.com/rogerchi/cdk-remix-app.git",
    "long_description_content_type": "text/markdown",
    "author": "Roger Chi<roger@rogerchi.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/rogerchi/cdk-remix-app.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_remix-app",
        "cdk_remix-app._jsii"
    ],
    "package_data": {
        "cdk_remix-app._jsii": [
            "cdk-remix-app@0.0.1.jsii.tgz"
        ],
        "cdk_remix-app": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.24.0, <3.0.0",
        "aws-cdk.aws-apigatewayv2-alpha>=2.24.0.a0, <3.0.0",
        "aws-cdk.aws-apigatewayv2-integrations-alpha>=2.24.0.a0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.72.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
